@@ -45,7 +45,6 @@
 #'   file_name = "mypng",
 #'   file_type = "PNG")
 #' }
-#' @import rsvg DiagrammeRsvg
 #' @importFrom utils installed.packages
 #' @export export_graph
 
@@ -85,7 +84,7 @@ export_graph <- function(graph,
   }
 
   if (file_type == "PNG" | file_type == "png") {
-    rsvg_png(
+    rsvg::rsvg_png(
       charToRaw(
         DiagrammeRsvg::export_svg(grViz(graph$dot_code))),
       file = file_name,
@@ -94,7 +93,7 @@ export_graph <- function(graph,
   }
 
   if (file_type == "PDF" | file_type == "pdf") {
-    rsvg_pdf(
+    rsvg::rsvg_pdf(
       charToRaw(
         DiagrammeRsvg::export_svg(grViz(graph$dot_code))),
       file = file_name,
@@ -103,7 +102,7 @@ export_graph <- function(graph,
   }
 
   if (file_type == "SVG" | file_type == "svg") {
-    rsvg_svg(
+    rsvg::rsvg_svg(
       charToRaw(
         DiagrammeRsvg::export_svg(grViz(graph$dot_code))),
       file = file_name,
@@ -112,7 +111,7 @@ export_graph <- function(graph,
   }
 
   if (file_type == "PS" | file_type == "ps") {
-    rsvg_ps(
+    rsvg::rsvg_ps(
       charToRaw(
         DiagrammeRsvg::export_svg(grViz(graph$dot_code))),
       file = file_name,
